dhg.experiments
==================

Base Class
-----------------

.. autoclass:: dhg.experiments.BaseTask
   :members:
   :show-inheritance:


Vertex Classification Task
---------------------------

.. autoclass:: dhg.experiments.VertexClassificationTask
   :members:
   :show-inheritance:


On Graph
++++++++++++++++++++++++++++++++++++++++++

.. autoclass:: dhg.experiments.GraphVertexClassificationTask
   :members:
   :show-inheritance:


On Hypergraph
++++++++++++++++++++++++++++++++++++++++++++++

.. autoclass:: dhg.experiments.HypergraphVertexClassificationTask
   :members:
   :show-inheritance:

Recommender Task
-------------------------

On User-Item Bipartite Graph
+++++++++++++++++++++++++++++++++++++++++++++++++++

.. autoclass:: dhg.experiments.UserItemRecommenderTask
   :members:
   :show-inheritance:
